# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import spotii_billing_client
from api.plugin_configurations_api import PluginConfigurationsApi  # noqa: E501
from spotii_billing_client.rest import ApiException


class TestPluginConfigurationsApi(unittest.TestCase):
    """PluginConfigurationsApi unit test stubs"""

    def setUp(self):
        self.api = api.plugin_configurations_api.PluginConfigurationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_plugin_configurations_create(self):
        """Test case for plugin_configurations_create

        Plugin configuration  # noqa: E501
        """
        pass

    def test_plugin_configurations_delete(self):
        """Test case for plugin_configurations_delete

        Plugin configuration  # noqa: E501
        """
        pass

    def test_plugin_configurations_list(self):
        """Test case for plugin_configurations_list

        Plugin configuration  # noqa: E501
        """
        pass

    def test_plugin_configurations_partial_update(self):
        """Test case for plugin_configurations_partial_update

        Plugin configuration  # noqa: E501
        """
        pass

    def test_plugin_configurations_read(self):
        """Test case for plugin_configurations_read

        Plugin configuration  # noqa: E501
        """
        pass

    def test_plugin_configurations_update(self):
        """Test case for plugin_configurations_update

        Plugin configuration  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
