# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import spotii_billing_client
from api.accounts_api import AccountsApi  # noqa: E501
from spotii_billing_client.rest import ApiException


class TestAccountsApi(unittest.TestCase):
    """AccountsApi unit test stubs"""

    def setUp(self):
        self.api = api.accounts_api.AccountsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_accounts_billing_addresses_create(self):
        """Test case for accounts_billing_addresses_create

        """
        pass

    def test_accounts_billing_addresses_default(self):
        """Test case for accounts_billing_addresses_default

        """
        pass

    def test_accounts_billing_addresses_delete(self):
        """Test case for accounts_billing_addresses_delete

        """
        pass

    def test_accounts_billing_addresses_list(self):
        """Test case for accounts_billing_addresses_list

        """
        pass

    def test_accounts_billing_addresses_partial_update(self):
        """Test case for accounts_billing_addresses_partial_update

        """
        pass

    def test_accounts_billing_addresses_read(self):
        """Test case for accounts_billing_addresses_read

        """
        pass

    def test_accounts_billing_addresses_update(self):
        """Test case for accounts_billing_addresses_update

        """
        pass

    def test_accounts_create(self):
        """Test case for accounts_create

        """
        pass

    def test_accounts_installments_create(self):
        """Test case for accounts_installments_create

        """
        pass

    def test_accounts_installments_delete(self):
        """Test case for accounts_installments_delete

        """
        pass

    def test_accounts_installments_list(self):
        """Test case for accounts_installments_list

        """
        pass

    def test_accounts_installments_read(self):
        """Test case for accounts_installments_read

        """
        pass

    def test_accounts_list(self):
        """Test case for accounts_list

        """
        pass

    def test_accounts_partial_update(self):
        """Test case for accounts_partial_update

        """
        pass

    def test_accounts_payment_methods_create(self):
        """Test case for accounts_payment_methods_create

        """
        pass

    def test_accounts_payment_methods_default(self):
        """Test case for accounts_payment_methods_default

        """
        pass

    def test_accounts_payment_methods_delete(self):
        """Test case for accounts_payment_methods_delete

        """
        pass

    def test_accounts_payment_methods_list(self):
        """Test case for accounts_payment_methods_list

        """
        pass

    def test_accounts_payment_methods_partial_update(self):
        """Test case for accounts_payment_methods_partial_update

        """
        pass

    def test_accounts_payment_methods_read(self):
        """Test case for accounts_payment_methods_read

        """
        pass

    def test_accounts_payment_methods_update(self):
        """Test case for accounts_payment_methods_update

        """
        pass

    def test_accounts_payments_list(self):
        """Test case for accounts_payments_list

        API endpoint that allow access to payment.  # noqa: E501
        """
        pass

    def test_accounts_payments_read(self):
        """Test case for accounts_payments_read

        API endpoint that allow access to payment.  # noqa: E501
        """
        pass

    def test_accounts_read(self):
        """Test case for accounts_read

        """
        pass

    def test_accounts_update(self):
        """Test case for accounts_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
