# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import spotii_billing_client
from api.billing_addresses_api import BillingAddressesApi  # noqa: E501
from spotii_billing_client.rest import ApiException


class TestBillingAddressesApi(unittest.TestCase):
    """BillingAddressesApi unit test stubs"""

    def setUp(self):
        self.api = api.billing_addresses_api.BillingAddressesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_billing_addresses_create(self):
        """Test case for billing_addresses_create

        """
        pass

    def test_billing_addresses_default(self):
        """Test case for billing_addresses_default

        """
        pass

    def test_billing_addresses_delete(self):
        """Test case for billing_addresses_delete

        """
        pass

    def test_billing_addresses_list(self):
        """Test case for billing_addresses_list

        """
        pass

    def test_billing_addresses_partial_update(self):
        """Test case for billing_addresses_partial_update

        """
        pass

    def test_billing_addresses_read(self):
        """Test case for billing_addresses_read

        """
        pass

    def test_billing_addresses_update(self):
        """Test case for billing_addresses_update

        """
        pass


if __name__ == '__main__':
    unittest.main()
