# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import spotii_billing_client
from api.installment_estimate_api import InstallmentEstimateApi  # noqa: E501
from spotii_billing_client.rest import ApiException


class TestInstallmentEstimateApi(unittest.TestCase):
    """InstallmentEstimateApi unit test stubs"""

    def setUp(self):
        self.api = api.installment_estimate_api.InstallmentEstimateApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_installment_estimate_create(self):
        """Test case for installment_estimate_create

        """
        pass


if __name__ == '__main__':
    unittest.main()
