# coding: utf-8

"""
    Spotii Billing API

    API for Billing  # noqa: E501

    OpenAPI spec version: v1.0
    Contact: hello@nuclearo.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import spotii_billing_client
from api.transactions_api import TransactionsApi  # noqa: E501
from spotii_billing_client.rest import ApiException


class TestTransactionsApi(unittest.TestCase):
    """TransactionsApi unit test stubs"""

    def setUp(self):
        self.api = api.transactions_api.TransactionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_transactions_list(self):
        """Test case for transactions_list

        API endpoint that allow access to payment transactions. Transaction belong to a Payment object.  # noqa: E501
        """
        pass

    def test_transactions_read(self):
        """Test case for transactions_read

        API endpoint that allow access to payment transactions. Transaction belong to a Payment object.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
